/*
 * led_receptor.c
 *
 * Created: 03/12/2021 14:29:43
 *  Author: 40008304
 */ 

#include "led_receptor.h"

void ADC_init(void)
{
	DDRB &=~(1<<PB3);										//Pin B3 en entree
	ADMUX |= (1<<MUX1)|(1<<MUX0)|(1<<ADLAR);				//MUX = 0010 donc sortie PB4 et ADLAR a 1 pour avoir les bits de poids fort en premier
	ADCSRA |= (1<<ADEN)|(1<<ADPS2);							//On divise 1Mhz par 16 (62.5 KHz) < 200 KHz, ADEN conversion autorisee
};

char ADC_read_value(void)
{
	ADCSRA|=(1<<ADSC);
	while(ADCSRA & (1<<ADSC));
	return ADCH;
};

float ADC_averaging(void)
{
	float valeur_finale=0;
	char precision;
	for(precision = 75; precision > 0 ; precision --)
	{
		valeur_finale = valeur_finale +(((ADC_read_value() * 0.01961) - valeur_finale) / 15);
	}
	return valeur_finale;
};

float measureLed1(void)
{
	float adcLed;
	led2_stop();
	led1_init();
	_delay_ms(TIMING);
	adcLed=ADC_averaging();
	_delay_ms(TIMING);
	return adcLed;
};

float measureLed2(void)
{
	float adcLed;
	led1_stop();
	led2_init();
	_delay_ms(TIMING);
	adcLed=ADC_averaging();
	_delay_ms(TIMING);
	return adcLed;
};

char compareLed(void)
{
	float adcLed1 = measureLed1();
	float adcLed2 = measureLed2();
	float adcCompare = adcLed1 - adcLed2;
	if (adcCompare < -VOLTMIN)	// adcLed2 > adcLed1
	{
		return LEFT;
	}
	else if (adcCompare > VOLTMIN)
	{
		return RIGHT;
	}
	else
	{
		if((adcLed1 > VOLTMIN) && (adcLed2 > VOLTMIN))
		{
			return FRONT;
		}
		else
		{
			return NOTHING;
		};
	};
};
